Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(539)

Unified Diff: chrome/browser/extensions/api/developer_private/extension_info_generator.h

Issue 1016413004: [Extensions] Update Error Console UI (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Dan's Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/developer_private/extension_info_generator.h
diff --git a/chrome/browser/extensions/api/developer_private/extension_info_generator.h b/chrome/browser/extensions/api/developer_private/extension_info_generator.h
index 9b50bfb3a55561a311052c543e46280bf5c7a336..7e23b79f3f38897f5e6cc6fad67cc683fb763c46 100644
--- a/chrome/browser/extensions/api/developer_private/extension_info_generator.h
+++ b/chrome/browser/extensions/api/developer_private/extension_info_generator.h
@@ -5,6 +5,7 @@
#ifndef CHROME_BROWSER_EXTENSIONS_API_DEVELOPER_PRIVATE_EXTENSION_INFO_GENERATOR_H_
#define CHROME_BROWSER_EXTENSIONS_API_DEVELOPER_PRIVATE_EXTENSION_INFO_GENERATOR_H_
+#include "base/memory/linked_ptr.h"
#include "chrome/common/extensions/api/developer_private.h"
namespace content {
@@ -16,6 +17,8 @@ class ErrorConsole;
class Extension;
class ExtensionPrefs;
class ExtensionSystem;
+class ManifestError;
+class RuntimeError;
Dan Beam 2015/04/22 21:02:37 Y U ADD?
Devlin 2015/04/22 23:17:31 Removed.
class WarningService;
// Generates the developerPrivate api's specification for ExtensionInfo.
@@ -27,12 +30,16 @@ class ExtensionInfoGenerator {
explicit ExtensionInfoGenerator(content::BrowserContext* context);
~ExtensionInfoGenerator();
- // Return the ExtensionInfo for a given |extension| and |state|.
+ // Returns the ExtensionInfo for a given |extension| and |state|.
scoped_ptr<api::developer_private::ExtensionInfo> CreateExtensionInfo(
const Extension& extension,
api::developer_private::ExtensionState state);
+ // Returns an ExtensionInfo for the given |extension_id|, if the extension
+ // can be found.
+ scoped_ptr<api::developer_private::ExtensionInfo> CreateExtensionInfo(
+ const std::string& id);
- // Return a collection of ExtensionInfos, optionally including disabled and
+ // Returns a collection of ExtensionInfos, optionally including disabled and
// terminated.
ExtensionInfoList CreateExtensionsInfo(bool include_disabled,
bool include_terminated);

Powered by Google App Engine
This is Rietveld 408576698